from behave import *
from volworld_common.test.behave.BehaveUtil import BehaveUtil
from volworld_aws_api_common.test.behave.ACotA import ACotA


def set_target_page(c, target_page: str):
    target_page = BehaveUtil.clear_string(target_page)
    setattr(c, ACotA.TargetPage, target_page)


@given('target page is [{target_page}]')
def given__set_target_page(c, target_page: str):
    set_target_page(c, target_page)


@when('target page is [{target_page}]')
def when__set_target_page(c, target_page: str):
    set_target_page(c, target_page)




from volworld_aws_api_common.test.wiremock.WiremockUtil import WiremockUtil


class Wiremock:

    ROOT_URL = f"http://localhost:00000"

    @staticmethod
    def rest_all_scenario():
        WiremockUtil.rest_all_scenario(Wiremock.ROOT_URL)
        # WiremockUtil.rest_all_scenario(Wiremock.ROOT_URL)

    @staticmethod
    def set_mock_state(url: str, state: str):
        WiremockUtil.set_mock_state(Wiremock.ROOT_URL, url, state)
        # WiremockUtil.set_mock_state(Wiremock.ROOT_URL, url, state)

    @staticmethod
    def set_scenario_state(scenario: str, state: str):
        WiremockUtil.set_scenario_state(Wiremock.ROOT_URL, scenario, state)


from behave import *
from volworld_aws_api_common.test.behave.row_utils import (
    update_order_type_of_list, w__tags_of_all_rows_are_showing, w__tags_of_all_rows_are_not_showing)


@when('{mentor} update [Order] type of list page to {sort_dir}')
def when_update_order_type_of_list_page(c, mentor: str, sort_dir: str):
    update_order_type_of_list(c, sort_dir)


@then('tags of all rows are showing')
def then_tags_of_all_rows_are_showing(c):
    w__tags_of_all_rows_are_showing(c)


@then('tags of all rows are not showing')
def then_tags_of_all_rows_are_not_showing(c):
    w__tags_of_all_rows_are_not_showing(c)